@@ -1,8 +1,9 @@
 //===- MCSectionELF.h - ELF Machine Code Sections ---------------*- C++ -*-===//
 //
-// Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions.
-// See https://llvm.org/LICENSE.txt for license information.
-// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
+//                     The LLVM Compiler Infrastructure
+//
+// This file is distributed under the University of Illinois Open Source
+// License. See LICENSE.TXT for details.
 //
 //===----------------------------------------------------------------------===//
 //
@@ -13,10 +14,12 @@
 #ifndef LLVM_MC_MCSECTIONELF_H
 #define LLVM_MC_MCSECTIONELF_H
 
-#include "llvm/ADT/StringRef.h"
+#include "llvm/ADT/Twine.h"
 #include "llvm/MC/MCSection.h"
 #include "llvm/MC/MCSymbolELF.h"
-#include "llvm/MC/SectionKind.h"
+#include "llvm/Support/Debug.h"
+#include "llvm/Support/ELF.h"
+#include "llvm/Support/raw_ostream.h"
 
 namespace llvm {
 
@@ -25,6 +28,10 @@ class MCSymbol;
 /// This represents a section on linux, lots of unix variants and some bare
 /// metal systems.
 class MCSectionELF final : public MCSection {
+  /// This is the name of the section.  The referenced memory is owned by
+  /// TargetLoweringObjectFileELF's ELFUniqueMap.
+  StringRef SectionName;
+
   /// This is the sh_type field of a section, drawn from the enums below.
   unsigned Type;
 
@@ -40,53 +47,46 @@ class MCSectionELF final : public MCSection {
 
   const MCSymbolELF *Group;
 
-  /// Used by SHF_LINK_ORDER. If non-null, the sh_link field will be set to the
-  /// section header index of the section where LinkedToSym is defined.
-  const MCSymbol *LinkedToSym;
+  /// Depending on the type of the section this is sh_link or sh_info.
+  const MCSectionELF *Associated;
 
 private:
   friend class MCContext;
-
-  // The storage of Name is owned by MCContext's ELFUniquingMap.
-  MCSectionELF(StringRef Name, unsigned type, unsigned flags, SectionKind K,
+  MCSectionELF(StringRef Section, unsigned type, unsigned flags, SectionKind K,
                unsigned entrySize, const MCSymbolELF *group, unsigned UniqueID,
-               MCSymbol *Begin, const MCSymbolELF *LinkedToSym)
-      : MCSection(SV_ELF, Name, K, Begin), Type(type), Flags(flags),
-        UniqueID(UniqueID), EntrySize(entrySize), Group(group),
-        LinkedToSym(LinkedToSym) {
+               MCSymbol *Begin, const MCSectionELF *Associated)
+      : MCSection(SV_ELF, K, Begin), SectionName(Section), Type(type),
+        Flags(flags), UniqueID(UniqueID), EntrySize(entrySize), Group(group),
+        Associated(Associated) {
     if (Group)
       Group->setIsSignature();
   }
 
-  // TODO Delete after we stop supporting generation of GNU-style .zdebug_*
-  // sections.
-  void setSectionName(StringRef Name) { this->Name = Name; }
+  void setSectionName(StringRef Name) { SectionName = Name; }
 
 public:
+  ~MCSectionELF();
+
   /// Decides whether a '.section' directive should be printed before the
   /// section name
   bool ShouldOmitSectionDirective(StringRef Name, const MCAsmInfo &MAI) const;
 
+  StringRef getSectionName() const { return SectionName; }
   unsigned getType() const { return Type; }
   unsigned getFlags() const { return Flags; }
   unsigned getEntrySize() const { return EntrySize; }
   void setFlags(unsigned F) { Flags = F; }
   const MCSymbolELF *getGroup() const { return Group; }
 
-  void PrintSwitchToSection(const MCAsmInfo &MAI, const Triple &T,
-                            raw_ostream &OS,
+  void PrintSwitchToSection(const MCAsmInfo &MAI, raw_ostream &OS,
                             const MCExpr *Subsection) const override;
   bool UseCodeAlign() const override;
   bool isVirtualSection() const override;
-  StringRef getVirtualSectionKind() const override;
 
-  bool isUnique() const { return UniqueID != NonUniqueID; }
+  bool isUnique() const { return UniqueID != ~0U; }
   unsigned getUniqueID() const { return UniqueID; }
 
-  const MCSection *getLinkedToSection() const {
-    return &LinkedToSym->getSection();
-  }
-  const MCSymbol *getLinkedToSymbol() const { return LinkedToSym; }
+  const MCSectionELF *getAssociatedSection() const { return Associated; }
 
   static bool classof(const MCSection *S) {
     return S->getVariant() == SV_ELF;
@@ -95,4 +95,4 @@ public:
 
 } // end namespace llvm
 
-#endif // LLVM_MC_MCSECTIONELF_H
+#endif
